"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const os = require("os");
const util_1 = require("util");
const types_1 = require("./types");
/**
 *  Clase para realizar un wrapper de la
 *  publicacion de logs sobre la cola
 *  de mensajes.
 */
class Logs {
    /**
     * Contructor de clase
     * @param send metodo send original
     * @param conf Configuracion del servicio
     * @constructor
     */
    constructor(send, conf) {
        // Asginar el send del objeto principal.
        this.send = send;
        // Configuracion
        this.conf = conf;
    }
    /**
     * Metodo para publicar un logs de tipo trace.
     * @param arg Arugmentos del loggers
     */
    trace(...arg) {
        this.publish(types_1.LogsTypes.Trace, arg);
    }
    /**
     * Metodo para publicar un logs de tipo debug.
     * @param arg Arugmentos del loggers
     */
    debug(...arg) {
        this.publish(types_1.LogsTypes.Debug, arg);
    }
    /**
     * Metodo para publicar un logs de tipo info.
     * @param arg Arugmentos del loggers
     */
    info(...arg) {
        this.publish(types_1.LogsTypes.Info, arg);
    }
    /**
     * Metodo para publicar un logs de tipo warning.
     * @param arg Arugmentos del loggers
     */
    warn(...arg) {
        this.publish(types_1.LogsTypes.Warn, arg);
    }
    /**
     * Metodo para publicar un logs de tipo error.
     * @param arg Arugmentos del loggers
     */
    error(...arg) {
        this.publish(types_1.LogsTypes.Error, arg);
    }
    /**
     * Metodo para publicar un logs de tipo fatal.
     * @param arg Arugmentos del loggers
     */
    fatal(...arg) {
        this.publish(types_1.LogsTypes.Fatal, arg);
    }
    /**
     * Metodo para realizar la publicacion de un logs
     * @param type Tipo del logs
     * @param arg Argumentos extra
     */
    publish(type, ...arg) {
        // Formato estandar del logs
        const logs = {
            hostname: os.hostname(),
            id: process.env.ID_INSTANCE || '',
            idApp: process.env.ID_APP || '',
            idComponent: process.env.ID_COMPONENT || '',
            level: type,
            msg: '',
            pid: process.pid,
            time: new Date().getTime(),
        };
        // Logs que se publicara sobre la cola de mensajes
        let resp = {};
        // Verificar que se hayan pasado los parametros necesario
        if (arg.length > 0) {
            // Ver si el primer elemento es un string
            if (util_1.isString(arg[0])) {
                // Asignar el mensaje
                logs.msg = arg[0];
                // Agregar el objeto
                resp = Object.assign(resp, logs, this.conf);
            }
            else if (util_1.isObject(arg[0])) {
                // asignar el mensaje
                logs.msg = arg[1];
                // Agregar el objeto
                resp = Object.assign(arg[0], logs, this.conf);
            }
            // Pasar a Base64
            const dataBuffer = Buffer.from(JSON.stringify(resp)).toString('base64');
            // Publicar el mensaje
            this.send(dataBuffer, process.env.LOGS_TOPIC || 'logs_system_coppelio');
        }
    }
}
exports.default = Logs;
